@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """Top-level package for src."""
 
-__author__ = """Thomas Scholtz"""
+__author__ = """Thomas Scholtz, Monté Bouwer"""
 __email__ = "thomas@labs.epiuse.com"
-__version__ = "__version__ = '10.0.4'"
+__version__ = "12.0.1"
